\name{B3}
\alias{B3}
\docType{data}
\title{West German Business Cycles 1955-1994}
\description{West German Business Cycles 1955-1994}
\usage{data(B3)}
\format{
  A data frame with 157 observations on the following 14 variables.
  \describe{
    \item{PHASEN}{a factor with levels \code{1} (upswing), 
        \code{2} (upper turning points), \code{3} (downswing), and \code{4} (lower turning points).}
    \item{BSP91JW}{GNP (y)}
    \item{CP91JW}{Private Consumption (y)}
    \item{DEFRATE}{Government deficit (percent of GNP)}
    \item{EWAJW}{Wage and salary earners (y)}
    \item{EXIMRATE}{Net exports as (percent of GNP)}
    \item{GM1JW}{Money supply M1 (y)}
    \item{IAU91JW}{Investment in equipment (y)}
    \item{IB91JW}{Investment in construction (y)}
    \item{LSTKJW}{Unit labor cost (y)}
    \item{PBSPJW}{GNP price deflator (y)}
    \item{PCPJW}{Consumer price index (y)}
    \item{ZINSK}{Short term interest rate (nominal)}
    \item{ZINSLR}{Long term interest rate (real)}
  }
  where (y) stands for \dQuote{yearly growth rates}.
  
  Note that years and corresponding year quarters are given in the row names of the data frame,
  e.g. \dQuote{1988,3} for the third quarter in 1988. 
}
\details{
The West German Business Cycles data (1955-1994) is analyzed by the project \emph{B3}
of the SFB475 (Collaborative Research Centre 
\dQuote{Reduction of Complexity for Multivariate Data Structures}),
supported by the Deutsche Forschungsgemeinschaft.
}
\source{
RWI (Rheinisch Westflisches Institut fr Wirtschaftsforschung), Essen, Germany.
}
\references{
Heilemann, U. and Mnch, H.J. (1996): 
    West German Business Cycles 1963-1994: A Multivariate Discriminant Analysis.
    \emph{CIRET--Conference in Singapore, CIRET--Studien} 50.
}
\examples{
data(B3)
summary(B3)
}
\keyword{datasets}

\eof
\name{EDAM}
\alias{EDAM}

\title{Computation of an Eight Direction Arranged Map}
\description{
  Produces an object of class \code{EDAM} which is a two dimensional representation 
  of data in a rectangular, equally spaced 
    grid as known from Self-Organizing Maps.
}
\usage{
EDAM(EV0, nzx = 0, iter.max = 10, random = TRUE, standardize = FALSE, 
    wghts = 0, classes = 0, sa = TRUE, temp.in = 0.5, temp.fin = 1e-07, 
    temp.gamma = 0)
}

\arguments{
  \item{EV0}{ either a symmetric dissimilarity matrix or a matrix of arbitrary dimensions whose 
                n rows correspond to cases and whose k columns correspond to variables. }
  \item{nzx}{ an integer specifying the number of vertical bars in the grid. By default, 
                \code{nzx} is chosen automatically, so that the grid
                gets closest do a square. If n is no multiple of \code{nzx}, all surplus objects are skipped.}
  \item{iter.max}{an integer giving the maxmimum number of iterations to perform for the same neighborhood size.}
  \item{random}{logical. If \code{TRUE}, the initital order is drawn from a uniform distribution.}
  \item{standardize}{logical. If \code{TRUE}, the measurements in \code{EV0} are standardized before 
        calculating Euclidean distances. 
        Measurements are standardized for each variable by dividing by the variable's 
        standard deviation. Meaningless if \code{EV0} is a dissimilarity matrix. }
  \item{wghts}{ an optional vector of length k giving relative weights of the variables in 
        computing Euclidean distances. Meaningless if \code{EV0} is a dissimilarity matrix. }
  \item{classes}{ an optional vector of length n specifying the membership to classes for all objects.}
  \item{sa}{logical. If \code{TRUE}, the optimization is obtained by Simulated Annealing.}
  \item{temp.in}{numeric giving the initial temperature, if \code{sa} is set to \code{TRUE}.}
  \item{temp.fin}{ numeric giving the final temperature, if \code{sa} is set to \code{TRUE}. 
        Meaningless if \code{temp.gamma} is greater than 0.}
  \item{temp.gamma}{ numeric giving the relative change of the temperature from one iteration to the other, 
        if \code{sa} is set to \code{TRUE}.}
}
\details{
  The data given by \code{EV0} is visualized by the EDAM-algorithm. This method approximates the best visualization where
  goodness is measured by \code{S}, a transformation of the criterion \code{stress} as i.e. 
  known from \code{\link[MASS]{sammon}}. 
  The target space of the visualization is restricted to a grid so the problem has a discrete solution space. 
  Originally this restriction was made to make the results
  comparable to those of Kohonen Self-Organizing Maps. But it turns out that also for reasons of a clear arrangement the
  representation in a grid can be more favorable than in the hole plane.
  
  During the computation of EDAM 3 values indicating its progress are given online. The first is the number of the actual
  iteration, the second the maximum number of overall performed iterations. The latter may reduce during computation,
  since the neighborhood reduces in case of convergence before the last iteration. 
  The last number gives the actual criterion S.
  The default plot method \code{plot.edam} for objects of class \code{EDAM} is \code{\link{shardsplot}}.
}
\value{
  EDAM returns an object of \code{class} \code{EDAM}, which is a list containing the following components:
  \item{preimages}{the re-ordered data; the position of the i-th object is where \code{Z} equals i.}
  \item{Z}{a matrix representing the positions of the \code{preimages} in the grid by their numbers.}
  \item{Z.old.terms}{a matrix representing the positions of the data in original order in the grid by their numbers.}
  \item{cl.ord}{a vector giving the re-ordered classes. All elements equal 1 if argument \code{classes} is undefined.}
  \item{S}{the criterion of the map} 
}
\references{
  Raabe, N. (2003).
  \emph{Vergleich von Kohonen Self-Organizing-Maps mit einem nichtsimultanen 
  Klassifikations- und Visualisierungsverfahren}.
  Diploma Thesis, Department of Statistics, University of Dortmund.
  \url{http://www.statistik.uni-dortmund.de/de/content/einrichtungen/lehrstuehle/personen/raabe/Diplomarbeit.pdf}.
}
\author{Nils Raabe}


\seealso{
    \code{\link{shardsplot}}, \code{\link{TopoS}}
}
\examples{
# Compute an Eight Directions Arranged Map for a random sample 
# of the iris data.
data(iris)
set.seed(1234)
iris.sample <- sample(150, 42)
irisEDAM <- EDAM(iris[iris.sample, 1:4], classes = iris[iris.sample, 5], 
    standardize = TRUE, iter.max = 3)
plot(irisEDAM, vertices = FALSE)
legend(3, 5, col = rainbow(3), legend = levels(iris[,5]), pch = 16)
print(irisEDAM)

# Construct clusters within the phases of the german business data 
# and visualize the centroids by EDAM.
data(B3)
phasemat <- lapply(1:4, function(x) B3[B3[,1] == x, 2:14])
subclasses <- lapply(phasemat, 
    function(x) cutree(hclust(dist(x)), k = round(nrow(x) / 4.47)))
centroids <- lapply(1:4, 
    function(y) apply(phasemat[[y]], 2, 
        function(x) by(x, subclasses[[y]], mean)))
centmat <- matrix(unlist(sapply(centroids, t)), ncol = 13, 
    byrow = TRUE, dimnames = list(NULL, colnames(centroids[[1]])))
centclasses <- unlist(lapply(1:4, 
    function(x) rep(x, unlist(lapply(centroids, nrow))[x])))
B3EDAM <- EDAM(centmat, classes = centclasses, standardize = TRUE, 
    iter.max = 6, rand = FALSE)
plot(B3EDAM, standardize = TRUE)
opar <- par(xpd = NA)
legend(4, 5.1, col = rainbow(4), pch = 16, xjust = 0.5, yjust = 0,
    ncol = 2, legend = c("upswing", "upper turning point", 
                         "downswing", "lower turning point"))
print(B3EDAM)
par(opar)
}
\keyword{multivariate}

\eof
\name{NaiveBayes}
\alias{NaiveBayes}
\alias{NaiveBayes.default}
\alias{NaiveBayes.formula}
\title{Naive Bayes Classifier}
\description{
  Computes the conditional a-posterior probabilities of a categorical
  class variable given independent predictor variables using
  the Bayes rule.
}
\usage{
\method{NaiveBayes}{formula}(formula, data, ..., subset, na.action = na.pass)
\method{NaiveBayes}{default}(x, grouping, prior, usekernel=FALSE, ...)
}
\arguments{
  \item{x}{a numeric matrix, or a data frame of categorical and/or
    numeric variables.}
  \item{grouping}{class vector.}
  \item{formula}{a formula of the form \code{class ~ x1 + x2 +
      \dots}. Interactions are not allowed.}
  \item{data}{a data frame of predictors (caegorical and/or
    numeric).}
  \item{prior}{the prior probabilities of class membership. If unspecified, 
    the class proportions for the training set are used. If present, 
    the probabilities should be specified in the order of the factor levels.}
  \item{usekernel}{if \code{TRUE} a kernel density estimate (\code{\link{density}})
    is used for denstity estimation. If \code{FALSE} a normal density is estimated.}
  \item{\dots}{arguments passed to \code{\link{density}}.}
  \item{subset}{for data given in a data frame, an index vector
    specifying the cases to be used in the
    training sample.  (NOTE: If given, this argument must be
    named.)}
  \item{na.action}{a function to specify the action to be taken if \code{NA}s are
          found. The default action is not to count them for the
          computation of the probability factors. An
          alternative is na.omit, which leads to rejection of cases
          with missing values on any required variable.  (NOTE: If
          given, this argument must be named.)}
}
\value{
  An object of class \code{"NaiveBayes"} including components:

  \item{apriori}{Class distribution for the dependent variable.}
  \item{tables}{A list of tables, one for each predictor variable. For each
    categorical variable a table giving, for each attribute level, the conditional
    probabilities given the target class. For each numeric variable, a
    table giving, for each target class, mean and standard deviation of
    the (sub-)variable or a object of \code{class} \code{\link{density}}.}
}
\details{
 This implementation of Naive Bayes as well as this help is based on the code by 
  David Meyer in the package e1071 but extended for kernel estimated densities and user 
  specified \code{prior} probabilities. 
  The standard naive Bayes classifier (at least this implementation)
  assumes independence of the predictor
  variables.
  }
\author{Karsten Luebke}
\seealso{\code{\link{predict.NaiveBayes}}\,code{\link{plot.NaiveBayes}},\code{\link[e1071]{naiveBayes}},\code{\link[MASS]{qda}}}
\examples{
data(iris)
m <- NaiveBayes(Species ~ ., data = iris)
}
\keyword{classif}
\keyword{category}

\eof
\name{TopoS}
\alias{TopoS}

\title{Computation of criterion S of a visualization}
\description{
  \code{TopoS} computes one version of the criterion \code{stress} as i.e. 
    known from \code{\link[MASS]{sammon}} for a given visualization.
}
\usage{
TopoS(EV.dist, Cells.dist)
}

\arguments{
  \item{EV.dist}{a symmetric distance matrix consisting of distances in the origin space (\code{dx})}
  \item{Cells.dist}{a symmetric distance matrix consisting of distances in the target space (\code{dy})}
}
\details{
  TopoS first performs a homogeneous linear regression where \code{dx} is predicted by \code{dy}. 
  Then the residual sum of squares of this regression is computed and divided by the sum of squared \code{dx}. 
  Finally one minus the square root of the latter result defines \code{S}.
}
\value{
  \code{TopoS} returns a numeric between zero and one which is the criterion \code{S} of the given visualization.
}

\author{Nils Raabe}


\seealso{\code{\link{EDAM}}}
\examples{
# Compute S for the MDS visualization of the german business data
data(B3)
plot(cmdscale(dist(B3[, 2:14])), col = rainbow(4)[B3[, 1]], pch = 16)
TopoS(dist(B3[, 2:14]), dist(cmdscale(dist(B3[, 2:14]))))
}
\keyword{internal}

\eof
\name{b.scal}
\alias{b.scal}

\title{Calculation of beta scaling parameters}
\description{
Calculates the scaling parameter for \code{\link{betascale}}.
}
\usage{
b.scal(member, grouping, dis = FALSE, eps = 1e-04)
}
\arguments{
  \item{member}{Membership values of an argmax classification method. 
                Eg. posterior probabilities of \code{\link[MASS]{lda}}. 
                Row-wise values must sum up to 1 and must be in the interval [0,1].}
  \item{grouping}{Class vector.}
  \item{dis}{Logical, whether to optimize the dispersion parameter in \code{\link{pbeta}}.}
  \item{eps}{Minimum variation of membership values. If variance is smaller than \code{eps},
     the values are treated as one point.}
}
\details{
With \code{\link{betascale}} and \code{b.scal}, membership values of an argmax classifier 
are scaled in such a way, that the mean membership value of those values which are assigned 
to each class reflect the mean correctness rate of that values.
This is done via \code{\link{qbeta}} and \code{\link{pbeta}} with the appropriate shape parameters. 
If \code{dis} is \code{TRUE}, it is tried that the variation of membership values 
is optimal for the accuracy relative to the correctness rate. 
If the variation of the membership values is less than \code{eps},
they are treated as one point and shifted towards the correctness rate.
}
\value{
  A list containing
  \item{model}{Estimated parameters for \code{\link{betascale}}.}
  \item{eps}{Value of \code{eps} from the call.}
  \item{member}{Scaled membership values.}
}
\references{Garczarek, Ursula Maria (2002): Classification rules in standardized partition spaces.
            Dissertation, University of Dortmund. 
            URL \url{http://eldorado.uni-dortmund.de:8080/FB5/ls7/forschung/2002/Garczarek}}
\author{Karsten Luebke, Uwe Ligges}
\seealso{\code{\link{betascale}}, \code{\link{e.scal}}}
\examples{
library(MASS)
data(B3)
pB3 <- predict(lda(PHASEN ~ ., data = B3))$posterior
pbB3 <- b.scal(pB3, B3$PHASEN, dis = TRUE)
ucpm(pB3, B3$PHASEN)
ucpm(pbB3$member, B3$PHASEN)
}
\keyword{classif}

\eof
\name{betascale}
\alias{betascale}
\title{Scale membership values according to a beta scaling}
\description{
Performs the scaling for beta scaling learned by \code{\link{b.scal}}.
}
\usage{
betascale(betaobj, member)
}

\arguments{
  \item{betaobj}{A model learned by \code{\link{b.scal}}.}
  \item{member}{Membership values to be scaled.}
}
\details{
See \code{\link{b.scal}}.
}
\value{
A matrix with the scaled membership values.
}
\seealso{\code{\link{b.scal}}, \code{\link{e.scal}}}
\examples{
library(MASS)
data(B3)
pB3 <- predict(lda(PHASEN ~ ., data = B3))$posterior
pbB3 <- b.scal(pB3, B3$PHASEN)
betascale(pbB3)
}
\keyword{classif}

\eof
\name{calc.trans}
\alias{calc.trans}
\title{Calculation of transition probabilities}
\description{
Function to estimate the probabilities of a time series to stay or change the state.
}
\usage{
calc.trans(x)
}
\arguments{
  \item{x}{(factor) vector of states}
}
\details{
To estimate the transition probabilities the empirical frequencies are counted.
}
\value{
The transition probabilities matrix. 
\code{x[i,j]} is the probability to change from state \code{i} to state \code{j}.
}
\author{Karsten Luebke}

\examples{
data(B3)
calc.trans(B3$PHASEN)
}
\keyword{ts}

\eof
\name{centerlines}
\alias{centerlines}
\title{Lines from classborders to the center}
\description{
Function which constructs the lines from the borders between 
two classes to the center. To be used in connection with
\code{\link{triplot}} and \code{\link{quadplot}}.
}
\usage{
centerlines(n)
}
\arguments{
  \item{n}{number of classes. Meaningful are \code{3} or \code{4}.}
}

\value{
a matrix with \code{n}-columns. 
}
\author{Karsten Luebke}

\seealso{\code{\link{triplot}}, \code{\link{quadplot}}}
\examples{
centerlines(3)
centerlines(4)
}
\keyword{classif}
\keyword{dplot}

\eof
\name{countries}
\alias{countries}
\docType{data}
\title{Socioeconomic data for the most populous countries.}
\description{
Socioeconomic data for the most populous countries.
}
\usage{data(countries)}
\format{
  A data frame with 42 observations on the following 7 variables.
  \describe{
    \item{Country}{name of the country.}
    \item{Popul}{population.}
    \item{PopDens}{population density.}
    \item{GDPpp}{GDP per inhabitant.}
    \item{LifeEx}{mean life expectation}
    \item{InfMor}{infant mortality}
    \item{Illit}{illiteracy rate}
  }
}

\source{
CIA World Factbook \url{http://www.cia.gov/cia/publications/factbook/}
}

\examples{
data(countries)
summary(countries)
}
\keyword{datasets}

\eof
\name{distmirr}
\alias{distmirr}

\title{Internal function to convert a distance structure to a matrix}
\description{
  For internal use only.
}
\usage{
distmirr(dis)
}

\arguments{
  \item{dis}{a distance structure as computed by \code{\link{dist}}}
}

\value{
  A symmetric distance matrix is returned.
}

 
\seealso{\code{\link{dist}}}
\keyword{internal}

\eof
\name{dkernel}
\alias{dkernel}
\title{Estimate density of a given kernel}
\description{
Given an estimated kernel density this function estimates the density of a new vector.
}
\usage{
dkernel(x, kernel = density(x), interpolate = FALSE)
}
\arguments{
  \item{x}{vector of which the density should be estimated}
  \item{kernel}{object of \code{class} \code{\link{density}}}
  \item{interpolate}{Interpolate or use \code{\link{density}} of nearest point?}
}
\value{
    Denstiy of \code{x} in \code{kernel}.
}
\author{Karsten Luebke}
\seealso{\code{\link{density}}, \code{\link{NaiveBayes}}}
\examples{
kern <- density(rnorm(50))
x <- seq(-3, 3, len = 100)
y <- dkernel(x, kern)
plot(x, y, type = "l")
}
\keyword{distribution}
\keyword{nonparametric}

\eof
\name{.dmvnorm}
\alias{.dmvnorm}
\title{Density of a Multivariate Normal Distribution}
\description{Intended for internal use only.}
\usage{
.dmvnorm(x, mu = NA, inv.sigma = NA, logDetCov = NA)
}
\arguments{
  \item{x}{}
  \item{mu}{}
  \item{inv.sigma}{}
  \item{logDetCov}{}
}
\keyword{internal}

\eof
\name{drawparti}
\alias{drawparti}

\title{Plotting the 2-d partitions of classification methods}
\description{
Plot showing the classification of observations based on 
classification methods (e.g. \code{lda}, \code{qda}) for two variables. 
Moreover, the classification borders are displayed and the apparent error rates are given in each title.
}
\usage{
drawparti(grouping, x, y, method = "lda", prec = 100, xlab = NULL, 
    ylab = NULL, col.correct = "black", col.wrong = "red", 
    col.mean = "black", col.contour = "darkgrey", 
    gs = as.character(grouping), pch.mean = 19, cex.mean = 1.3, 
    print.err = 0.7, legend.err = FALSE, legend.bg = "white",
    imageplot = TRUE, image.colors = cm.colors(nc), ...)        
}

\arguments{
  \item{grouping}{factor specifying the class for each observation.}
  \item{x}{first explanatory vector.}
  \item{y}{second explanatory vector.}
  \item{method}{the method the classification is based on, currently supported are:
      \code{\link[MASS]{lda}}, \code{\link[MASS]{qda}}, \code{\link[rpart]{rpart}}, \code{\link[e1071]{naiveBayes}}, 
      \code{\link{rda}}, \code{\link{sknn}} and \code{\link{svmlight}}}.
  \item{prec}{precision used to draw the classification borders (the higher the more precise; default: 100).}
  \item{xlab}{a title for the x axis.}
  \item{ylab}{a title for the y axis.}
  \item{col.correct}{color for correct classified objects.}
  \item{col.wrong}{color for wrong classified objects.}
  \item{col.mean}{color for class means (only for methods \code{lda} and \code{qda}).}
  \item{col.contour}{color of the contour lines (if \code{imageplot = FALSE}).}
  \item{gs}{group symbol (plot character), must have the same length as \code{grouping}.}            
  \item{pch.mean}{plot character for class means (only for methods \code{lda} and \code{qda}).}
  \item{cex.mean}{character expansion for class means (only for methods \code{lda} and \code{qda}).}
  \item{print.err}{character expansion for text specifying the apparent error rate. 
    If \code{print.err = 0}, nothing is printed.}
  \item{legend.err}{logical; whether to plot the apparent error rate above the plot (if \code{FALSE}),
    or into a legend into the upper right corner of the plot (if \code{TRUE}). 
    This argument is ignored, if \code{print.err = 0}, i.e. if no error rate is printed.}
  \item{legend.bg}{Backgound colour to use for the legend.}
  \item{imageplot}{logical; whether to use an \code{\link{image}} plot or \code{\link{contour}} lines.}
  \item{image.colors}{colors used for the \code{imageplot}, if TRUE.}
  \item{...}{Further arguments passed to the classification \code{method} 
    and underlying plot functions.}
}
\seealso{\code{\link{partimat}}}
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}, Uwe Ligges, Irina Czogiel}
\keyword{classif}
\keyword{dplot}

\eof
\name{e.scal}
\alias{e.scal}
\title{Function to calculate e- or softmax scaled membership values}
\description{
Calculates the e- or softmax scaled membership values of an argmax based classification rule.
}
\usage{
e.scal(x, k = 1, tc = NULL)
}
\arguments{
  \item{x}{matrix of membership values}
  \item{k}{parameter for e-scaling (1 for softmax)}
  \item{tc}{vector of true classes (required if \code{k} has to be optimized)}
}
\details{
For any  membership vector y \eqn{\exp(y\cdot k) / \sum\exp(y\cdot k)}{exp(y*k) / sum(exp(y*k)} is calculated. 
If \code{k=1}, the classical softmax scaling is used. If the true classes are given, \code{k} is optimized 
so that the apparent error rate is minimized.
}
\value{
A list containing elements
  \item{sv}{Scaled values}
  \item{k}{Optimal \code{k}}
}
\references{Garczarek, Ursula Maria (2002): Classification rules in standardized partition spaces.
            Dissertation, University of Dortmund. 
            URL \url{http://eldorado.uni-dortmund.de:8080/FB5/ls7/forschung/2002/Garczarek}}

\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}}

\examples{
library(MASS)
data(iris)
ldaobj <- lda(Species ~ ., data = iris)
ldapred <- predict(ldaobj)$posterior
e.scal(ldapred)
e.scal(ldapred, tc = iris$Species)
}
\keyword{classif}

\eof
\name{errormatrix}
\alias{errormatrix}
\title{Tabulation of prediction errors by classes}
\description{
Cross-tabulates true and predicted classes 
with the option to show relative frequencies.
}
\usage{
errormatrix(true, predicted, relative = FALSE)
}
\arguments{
\item{true}{Vector of true classes.}
\item{predicted}{Vector of predicted classes.}
\item{relative}{Logical. If \code{TRUE} rows are normalized
to show relative frequencies (see below).}
}
\details{
Given vectors of true and predicted classes, a (symmetric) 
table of misclassifications is constructed.

Element [i,j] shows the number of objects of class i that 
were classified as class j; so the main diagonal shows the 
correct classifications. The last row and column show the
corresponding sums of misclassifications, the lower right 
element is the total sum of misclassifications.

If \sQuote{\code{relative}} is \code{TRUE}, the \emph{rows} are 
normalized so they show relative frequencies instead. The 
lower right element now shows the total error rate, and the
remaining last row sums up to one, so it shows \dQuote{where the
misclassifications went}.
}
\note{
Concerning the case that \sQuote{\code{relative}} is \code{TRUE}:

If a prior distribution over the classes is given, the 
misclassification rate that is returned as the lower right 
element (which is only the fraction of misclassified 
\emph{data}) is not an estimator for the expected 
misclassification rate.

In that case you have to multiply the individual error rates for 
each class (returned in the last column) with the corresponding
prior probabilities and sum these up (see example below).

Both error rate estimates are equal, if the fractions of classes 
in the data are equal to the prior probabilities.
}
\value{
A (named) matrix.
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{\code{\link{table}}}
\examples{
data(iris)
library(MASS)
x <- lda(Species ~ Sepal.Length + Sepal.Width, data=iris)
y <- predict(x, iris)

# absolute numbers: 
errormatrix(iris$Species, y$class)

# relative frequencies: 
errormatrix(iris$Species, y$class, relative = TRUE)

# percentages: 
round(100 * errormatrix(iris$Species, y$class, relative = TRUE), 0)

# expected error rate in case of class prior: 
indiv.rates <- errormatrix(iris$Species, y$class, relative = TRUE)[1:3, 4]
prior <- c("setosa" = 0.2, "versicolor" = 0.3, "virginica" = 0.5)
total.rate <- t(indiv.rates) \%*\% prior
total.rate
}
\keyword{multivariate}

\eof
\name{hmm.sop}
\alias{hmm.sop}
\title{Calculation of HMM Sum of Path}
\description{
A Hidden Markov Model for the classification of states in a time series. 
Based on the transition probabilities and the so called emission probabilities
(\eqn{p(class|x)}{p(class|x)}) the \sQuote{prior probablilities} of states (classes) in time period \emph{t} 
given all past information in time period \emph{t} are calculated.
}
\usage{
hmm.sop(sv, trans.matrix, prob.matrix)
}
\arguments{
  \item{sv}{state at time 0}
  \item{trans.matrix}{matrix of transition probabilities}
  \item{prob.matrix}{matrix of \eqn{p(class|x)}{p(class|x)}}
}

\value{
Returns the \sQuote{prior probablilities} of states. 
}

\references{Garczarek, Ursula Maria (2002): Classification rules in standardized partition spaces.
            Dissertation, University of Dortmund. 
            URL \url{http://eldorado.uni-dortmund.de:8080/FB5/ls7/forschung/2002/Garczarek}}

\author{Daniel Fischer, Reinald Oetsch}


\seealso{\code{\link{calc.trans}}}
\examples{
library(MASS)
data(B3)
trans.matrix <- calc.trans(B3$PHASEN)

# Calculate posterior prob. for the classes via lda
prob.matrix <- predict(lda(PHASEN ~ ., data = B3))$post
errormatrix(B3$PHASEN, apply(prob.matrix, 1, which.max))
prior.prob <- hmm.sop("2", trans.matrix, prob.matrix)
errormatrix(B3$PHASEN, apply(prior.prob, 1, which.max))
}
\keyword{ts}
\keyword{classif}

\eof
\name{partimat}
\alias{partimat}
\alias{partimat.default}
\alias{partimat.formula}
\alias{partimat.data.frame}
\alias{partimat.matrix}

\title{Plotting the 2-d partitions of classification methods}
\description{
Provides a multiple figure array which shows the classification of observations based on 
classification methods (e.g. \code{lda}, \code{qda}) for every combination of two variables. 
Moreover, the classification borders are displayed and the apparent error rates are given in each title.
}
\usage{
partimat(x,...)

\method{partimat}{default}(x, grouping, method = "lda", prec = 100, 
    nplots.vert, nplots.hor, main = "Partition Plot", name, mar, 
    plot.matrix = FALSE, ...)
\method{partimat}{data.frame}(x, ...)
\method{partimat}{matrix}(x, grouping, ..., subset, na.action = na.fail)
\method{partimat}{formula}(formula, data = NULL, ..., subset, na.action = na.fail)
}


\arguments{
  \item{x}{matrix or data frame containing the explanatory variables (required, if \code{formula} is not given).}
  \item{grouping}{factor specifying the class for each observation (required, if \code{formula} is not given).}
  \item{formula}{formula of the form \code{groups ~ x1 + x2 + ...}. 
    That is, the response is the grouping factor and the right hand side specifies the (non-factor) discriminators. }
  \item{method}{the method the classification is based on, currently supported are:
  \code{\link[MASS]{lda}}, \code{\link[MASS]{qda}}, \code{\link[rpart]{rpart}}, \code{\link[e1071]{naiveBayes}}, 
  \code{\link{rda}}, \code{\link{sknn}} and \code{\link{svmlight}}}.
  \item{prec}{precision used to draw the classification borders (the higher the more precise; default: 100).}
  \item{data}{Data frame from which variables specified in formula are preferentially to be taken.}
  \item{nplots.vert}{number of rows in the multiple figure array}
  \item{nplots.hor}{number of columns in the multiple figure array}
  \item{subset}{index vector specifying the cases to be used in the
    training sample. (Note: If given, this argument must be named.)}
  \item{na.action}{specify the action to be taken if \code{NA}s are
    found. The default action is for the procedure to fail. An
    alternative is \code{\link{na.omit}}, which leads to rejection of cases with
    missing values on any required variable. (Note: If given, this argument must be named.) }
  \item{main}{title}
  \item{name}{Variable names to be printed at the axis / into the diagonal.}
  \item{mar}{numerical vector of the form \code{c(bottom, left, top, right)}
    which gives the lines of margin to be specified on the four sides of the plot.
    Defaults are \code{rep(0, 4)} if \code{plot.matrix = TRUE}, \code{c(5, 4, 2, 1) + 0.1} otherwise.}
  \item{plot.matrix}{logical; if \code{TRUE}, like a scatterplot matrix; 
    if \code{FALSE} (default) uses less space and arranges the plots \dQuote{optimal} 
    (using a fuzzy algorithm) in an array by plotting each pair of variables once.}
  \item{...}{Further arguments passed to the classification \code{method} 
    and underlying plot function \code{\link{drawparti}}.}
}
\seealso{for much more fine tuning see \code{\link{drawparti}}}
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}, Uwe Ligges, Irina Czogiel}
\note{Warnings such as  \sQuote{parameter \dQuote{xyz} couldn't be set in high-level plot function} are expected,
    if making use of \code{...}.}
\examples{
library(MASS)
data(iris)
partimat(Species ~ ., data = iris, method = "lda")
\dontrun{
partimat(Species ~ ., data = iris, method = "lda", 
    plot.matrix = TRUE, imageplot = FALSE) # takes some time ...
}
}
\keyword{classif}
\keyword{dplot}

\eof
\name{plot.NaiveBayes}
\alias{plot.NaiveBayes}
\title{Naive Bayes Plot}
\description{
  Visualizes the marginal probabilities of predictor variables 
  given the class.
}
\usage{
plot.NaiveBayes(x, vars, n = 1000, legendplot = TRUE, 
    lty = 1:length(x$apriori), col = rainbow(length(x$apriori)), 
    ylab = "Density", main = "Naive Bayes Plot", ...)
    }

\arguments{
  \item{x}{an object of \code{class} \code{\link{NaiveBayes}}}
  \item{vars}{variables to be plotted. If \code{missing} all predictor variables are plotted.}
  \item{n}{Number points used to plot the density line.}
  \item{legendplot}{print a \code{\link{legend}}?}
  \item{lty}{\code{lty} of the different classes.}
  \item{col}{\code{color} for the different classes.}
  \item{ylab}{label for y-axis.}
  \item{main}{title of the plots.}
  \item{\dots}{furhter arguments passed to the underlying plot functions.}
}
\details{
 For metric variables the estimated density is plotted. For categorial variables \code{\link{mosaicplot} is called.}
}

\author{Karsten Luebke}

\seealso{\code{\link{NaiveBayes}}}
\examples{
data(iris)
mN<-NaiveBayes(Species~.,data=iris)
plot(mN)

mK<-NaiveBayes(Species~.,data=iris,usekernel=TRUE)
plot(mK)
}
\keyword{classif}
\keyword{dplot}

\eof
\name{predict.NaiveBayes}
\alias{predict.NaiveBayes}
\title{Naive Bayes Classifier}
\description{
  Computes the conditional a-posterior probabilities of a categorical
  class variable given independent predictor variables using
  the Bayes rule.
}
\usage{
predict.NaiveBayes(object, newdata, threshold = 0.001, ...)
}
\arguments{
  \item{object}{An object of class \code{"naiveBayes"}.}
  \item{newdata}{A dataframe with new predictors.}
  \item{threshold}{Value replacing cells with 0 probabilities.}
  \item{\dots}{passed to \code{\link{dkernel}} function if neccessary.}
}
\value{
A list with the conditional a-posterior
probabilities for each class and the estimated class are returned.
}
\details{
  This implementation of Naive Bayes as well as this help is based on the code by 
  David Meyer in the package e1071 but extended for kernel estimated densities.
  The standard naive Bayes classifier (at least this implementation)
  assumes independence of the predictor
  variables. For attributes with missing values, the
  corresponding table entries are omitted for prediction.
}
\author{Karsten Luebke}
\seealso{\code{\link{NaiveBayes}},\code{\link{dkernel}}\code{\link[e1071]{naiveBayes}},\code{\link[MASS]{qda}}}
\examples{

data(iris)
m <- NaiveBayes(Species ~ ., data = iris)
predict(m)
}
\keyword{classif}
\keyword{category}

\eof
\name{predict.rda}
\alias{predict.rda}
\title{Regularized Discriminant Analysis (RDA)}
\description{
Classifies new observations using parameters determined by 
the \code{rda}-function.
}
\usage{
\method{predict}{rda}(object, newdata, posterior = TRUE, 
    aslist = TRUE,...)
}
\arguments{
\item{object}{Object of class \code{rda}.}
\item{newdata}{Data frame (or matrix) of cases to be classified.}
\item{posterior}{Logical; indicates whether a matrix of 
posterior probabilites over all classes for each observation 
shall be returned in addition to classifications.}
\item{aslist}{Logical; if \code{TRUE}, a list
containing classifications and posterior probabilities is returned, 
otherwise a vector with an attribute \sQuote{\code{posterior}}.}
\item{...}{}
}
\value{
Depends on the value of argument \sQuote{\code{aslist}}:

Either a vector (of class \code{factor}) of classifications 
that (optionally) has an attribute \sQuote{\code{posterior}} 
containing the posterior probability matrix, or

A list with elements \sQuote{\code{class}} and \sQuote{\code{posterior}}.
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{
  \code{\link[klaR]{rda}}
}
\examples{
data(iris)
x <- rda(Species ~ ., data = iris, gamma = 0.05, lambda = 0.2)
predict(x, iris[, 1:4])
}
\keyword{multivariate}

\eof
\name{predict.sknn}
\alias{predict.sknn}
\title{Simple k Nearest Neighbours Classification}
\description{
Classifies new observations using the sknn learned by 
the \code{sknn}-function.
}
\usage{
\method{predict}{sknn}(object, newdata,...)
}
\arguments{
\item{object}{Object of class \code{\link{sknn}}.}
\item{newdata}{Data frame (or matrix) of cases to be classified.}
\item{...}{...}
}
\value{
A list with elements \sQuote{\code{class}} and \sQuote{\code{posterior}}.
}
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}}
\seealso{
  \code{\link{sknn}}, \code{\link[class]{knn}}
}
\examples{
data(iris)
x <- sknn(Species ~ ., data = iris)
predict(x, iris)
}
\keyword{classif}

\eof
\name{predict.svmlight}
\alias{predict.svmlight}
\title{Interface to SVMlight}
\description{
Predicts new observations using the SVM learned by 
the \code{svmlight}-function.
}
\usage{
\method{predict}{svmlight}(object, newdata, scal = TRUE, ...)
}
\arguments{
\item{object}{Object of class \code{\link{svmlight}}.}
\item{newdata}{Data frame (or matrix) of cases to be predicted.}
\item{scal}{Logical, whether to scale membership values via \code{\link{e.scal}}.}
\item{...}{\dots}
}
\value{
If a classification is learned (\code{type="C"}) in \code{\link{svmlight}} a 
list with elements \sQuote{\code{class}} and \sQuote{\code{posterior}} (scaled, if \code{scal = TRUE}).

If a Regression is learned (\code{type="R"}) in \code{\link{svmlight}} the predicted values.
}
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}}
\seealso{
  \code{\link{svmlight}}, \code{\link[e1071]{svm}}
}
\examples{
\dontrun{
data(iris)
x <- svmlight(Species ~ ., data = iris)
predict(x, iris)
}
}
\keyword{classif}

\eof
\name{quadplot}
\alias{quadplot}
\title{Plotting of 4 dimensional membership representation simplex}
\description{
For a 4 class discrimination problem the membership values of each class are visualized in
a 3 dimensional barycentric coordinate system.
}
\usage{
quadplot(e = NULL, f = NULL, g = NULL, h = NULL, angle = 75, 
    scale.y = 0.6, label = 1:4, labelcol = rainbow(4), 
    labelpch = 19, labelcex = 1.5, main = "", s3d.control = list(), 
    simplex.control = list(), legend.control = list(), ...)
}
\arguments{
  \item{e}{either a matrix with 4 columns represanting the membership values or a 
            vector with the membership values of the first class}
  \item{f}{vector with the membership values of the second class}
  \item{g}{vector with the membership values of the third class}
  \item{h}{vector with the membership values of the forth class}
  \item{angle}{angle between x and y axis }
  \item{scale.y}{scale of y axis related to x- and z axis}
  \item{label}{label for the classes }
  \item{labelcol}{colors to use for the labels}
  \item{labelpch}{\code{pch} for the labels}
  \item{labelcex}{\code{cex} for the labels}
  \item{main}{main title of the plot}
  \item{s3d.control}{a \emph{list} with further arguments passed to the underlying 
    \code{\link[scatterplot3d]{scatterplot3d}} function call that sets up the plot}
  \item{simplex.control}{a \emph{list} with further arguments passed to the underlying 
    function call that draws the barycentric coordinate system}
  \item{legend.control}{a \emph{list} with further arguments passed to the underlying 
    function call that adds the \code{\link{legend}}}
  \item{\dots}{further arguments passed to the underlying \code{plot} function that draws the data points}
}
\details{
The membership values are calculated with \code{\link{quadtrafo}} and plotted 
with \code{\link[scatterplot3d]{scatterplot3d}}.
}
\value{
A \code{\link[scatterplot3d]{scatterplot3d}} object.
}

\references{Garczarek, Ursula Maria (2002): Classification rules in standardized partition spaces.
            Dissertation, University of Dortmund. 
            URL \url{http://eldorado.uni-dortmund.de:8080/FB5/ls7/forschung/2002/Garczarek}}

\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}, and Uwe Ligges}

\seealso{\code{\link{triplot}}, \code{\link[scatterplot3d]{scatterplot3d}}}
\examples{
library("MASS")
data(B3)
opar <- par(mfrow = c(1, 2), pty = "s")
posterior <- predict(lda(PHASEN ~ ., data = B3))$post
s3d <- quadplot(posterior, col = rainbow(4)[B3$PHASEN], 
        labelpch = 22:25, labelcex = 0.8,
        pch = (22:25)[apply(posterior, 1, which.max)], 
        main = "LDA posterior assignments")
quadlines(centerlines(4), sp = s3d, lty = "dashed")

posterior <- predict(qda(PHASEN ~ ., data = B3))$post
s3d <- quadplot(posterior, col = rainbow(4)[B3$PHASEN], 
        labelpch = 22:25, labelcex = 0.8,
        pch = (22:25)[apply(posterior, 1, which.max)],
        main = "QDA posterior assignments")
quadlines(centerlines(4), sp = s3d, lty = "dashed")
par(opar)
}
\keyword{classif}
\keyword{dplot}

\eof
\name{quadtrafo}
\alias{quadtrafo}
\alias{quadpoints}
\alias{quadlines}

\title{Transforming of 4 dimensional values in a barycentric coordinate system.}
\description{
Transforming of 4 dimensional values in a barycentric coordinate system.
}
\usage{
quadtrafo(e, f = NULL, g = NULL, h = NULL)
        
quadlines(e, f = NULL, g = NULL, h = NULL, sp = s3d, ...)

quadpoints(e, f = NULL, g = NULL, h = NULL, sp = s3d, ...)
}
\arguments{
  \item{e}{either a matrix with 4 columns represanting the membership values or a 
            vector with the membership values of the first class}
  \item{f}{vector with the membership values of the second class}
  \item{g}{vector with the membership values of the third class}
  \item{h}{vector with the membership values of the forth class}
  \item{sp}{\code{scatterplot3d} object to which \code{points} or \code{lines} should be plotted}
  \item{\dots}{further arguments passed to the underlyind \code{plot} functions}
}
\details{

}
\value{
For \code{quadtrafo} the 3 dimensional values in the barycentrix coordinate system. 
}

\author{Karsten Luebke}

\seealso{\code{\link{triplot}}, \code{\link{quadplot}}}
\examples{
library(MASS)
data(B3)
posterior <- predict(lda(PHASEN ~ ., data = B3))$post
quadtrafo(posterior)
}
\keyword{internal}

\eof
\name{rda}
\alias{rda}
\alias{rda.default}
\alias{rda.formula}
\alias{plot.rda}
\alias{print.rda}
\title{Regularized Discriminant Analysis (RDA)}
\description{
Builds a classification rule using regularized group covariance 
matrices that are supposed to be more robust against 
multicollinearity in the data.
}
\usage{
rda(x, ...)

\method{rda}{default}(x, grouping = NULL, prior = NULL, gamma = NA, 
    lambda = NA, regularization = c(gamma = gamma, lambda = lambda), 
    crossval = TRUE, fold = 10, train.fraction = 0.5, 
    estimate.error = TRUE, output = FALSE, startsimplex = NULL, 
    max.iter = 100, trafo = TRUE, simAnn = FALSE, schedule = 2, 
    T.start = 0.1, halflife = 50, zero.temp = 0.01, alpha = 2, 
    K = 100, ...)
\method{rda}{formula}(formula, data, ...)
}
\arguments{
\item{x}{Matrix or data frame containing the explanatory variables 
    (required, if \code{formula} is not given).}
\item{formula}{Formula of the form \sQuote{\code{groups ~ x1 + x2 + ...}}.}
\item{data}{A data frame (or matrix) containing the explanatory 
    variables.}
\item{grouping}{(Optional) a vector specifying the class for 
    each observation; if not specified, the first column of 
    \sQuote{\code{data}} is taken.}
\item{prior}{(Optional) prior probabilities for the classes. 
    Default: proportional to training sample sizes. 
    \dQuote{\code{prior=1}} indicates equally likely classes.}
\item{gamma, lambda, regularization}{
    One or both of the rda-parameters may be fixed manually. 
    Unspecified parameters are determined by minimizing the 
    estimated error rate (see below).}
\item{crossval}{Logical. If \code{TRUE}, in the optimization 
    step the error rate is estimated by Cross-Validation, 
    otherwise by drawing several training- and test-samples.}
\item{fold}{The number of Cross-Validation- or Bootstrap-samples
    to be drawn.}
\item{train.fraction}{In case of Bootstrapping: the fraction of 
    the data to be used for training in each Bootstrap-sample; 
    the remainder is used to estimate the misclassification rate.}
\item{estimate.error}{Logical. If \code{TRUE}, the apparent 
    error rate for the final parameter set is estimated.}
\item{output}{Logical flag to indicate whether text output 
    during computation is desired.}
\item{startsimplex}{(Optional) a starting simplex for the 
    Nelder-Mead-minimization.}
\item{max.iter}{Maximum number of iterations for Nelder-Mead.}
\item{trafo}{Logical; indicates whether minimization is carrried 
    out using transformed parameters.}
\item{simAnn}{Logical; indicates whether Simulated Annealing 
    shall be used.}
\item{schedule}{Annealing schedule 1 or 2 (exponential or polynomial).}
\item{T.start}{Starting temperature for Simulated Annealing.}
\item{halflife}{Number of iterations until temperature is reduced to a half  (schedule 1).}
\item{zero.temp}{Temperature at which it is set to zero  (schedule 1).} 
\item{alpha}{Power of temperature reduction (linear, quadratic, cubic,...)  (schedule 2).}
\item{K}{Number of iterations until temperature = 0  (schedule 2).}
\item{...}{}
}
\details{
J.H. Friedman (see references below) suggested a method to fix 
almost singular covariance matrices in discriminant analysis. 
Basically, individual covariances as in QDA are used, but 
depending on two parameters (\eqn{\gamma}{gamma} and 
\eqn{\lambda}{lambda}), these can be shifted towards a 
diagonal matrix and/or the pooled covariance 
matrix. For (\eqn{\gamma=0}{gamma=0}, \eqn{\lambda=0}{lambda=0}) it equals QDA, 
for (\eqn{\gamma=0}{gamma=0}, \eqn{\lambda=1}{lambda=1}) it equals LDA.

You may fix these parameters at certain values or leave it to 
the function to try to find \dQuote{optimal} values. If one 
parameter is given, the other one is determined using the 
R-function \sQuote{\code{\link{optimize}}}. If no parameter is 
given, both are determined numerically by a 
Nelder-Mead-(Simplex-)algorithm with the option of using 
Simulated Annealing.
The goal function to be minimized is the (estimated) 
misclassification rate; the misclassification rate is estimated 
either by Cross-Validation or by repeatedly dividing the data 
into training- and test-sets (Boostrapping).

Since the Nelder-Mead-algorithm is actually intended for 
\emph{continuous} functions while the observed error rate 
by its nature is \emph{discrete}, a greater number of 
Boostrap-samples might improve the optimization by increasing 
the smoothness of the response surface (and, of course, by 
reducing variance and bias). 
If a set of parameters leads to singular covariance 
matrices, a penalty term is added to the misclassification rate 
which will hopefully help to maneuver back out of singularity
(so do not worry about error rates greater than one during 
optimization).
}

\section{More details}{
The explicit defintion of \eqn{\gamma}{gamma},
\eqn{\lambda}{lambda} and the resulting covariance estimates
is as follows:

The pooled covariance estimate \eqn{\hat{\Sigma}}{SigmaHat} is 
given as well as the individual covariance estimates 
\eqn{\hat{\Sigma}_k}{SigmaHat_k} for each group.

First, using \eqn{\lambda}{lambda}, a convex combination of 
these two is computed:
\deqn{\hat{\Sigma}_k (\lambda) := (1-\lambda) \hat{\Sigma}_k + \lambda \hat{\Sigma}.}{%
SigmaHat_k(lambda) := (1-lambda)*SigmaHat_k + lambda*SigmaHat.}
Then, another convex combination is constructed using the 
above estimate and a (scaled) identity matrix:
\deqn{\hat{\Sigma}_k (\lambda,\gamma) = (1-\gamma)\hat{\Sigma}_k(\lambda)+
\gamma\frac{1}{d}\mathrm{tr}[\hat{\Sigma}_k(\lambda)]\mathrm{I}.}{%
SigmaHat_k(lambda,gamma) := (1-gamma) SigmaHat_k(lambda) 
+ gamma 1/d trace(SigmaHat_k(lambda)) I.}
The factor 
\eqn{\frac{1}{d}\mathrm{tr}[\hat{\Sigma}_k(\lambda)]}{1/d trace(SigmaHat_k(lambda))}
in front of the identity matrix I is the mean of the diagonal 
elements of 
\eqn{\hat{\Sigma}_k(\lambda)}{SigmaHat_k(lambda)}, so it is 
the mean variance of all \eqn{d} variables assuming the group 
covariance \eqn{\hat{\Sigma}_k(\lambda)}{SigmaHat_k(lambda)}.

For the four extremes of (\eqn{\gamma}{gamma},\eqn{\lambda}{lambda}) 
the covariance structure reduces to special cases:
\itemize{
\item (\eqn{\gamma=0}{gamma=0}, \eqn{\lambda=0}{lambda=0}): 
QDA - individual covariance for each group.
\item (\eqn{\gamma=0}{gamma=0}, \eqn{\lambda=1}{lambda=1}): 
LDA - a common covariance matrix.
\item (\eqn{\gamma=1}{gamma=1}, \eqn{\lambda=0}{lambda=0}): 
Conditional independent variables - similar to Naive Bayes,
but variable variances within group (main diagonal elements) 
are equal.
\item (\eqn{\gamma=1}{gamma=1}, \eqn{\lambda=1}{lambda=1}):
Classification using euclidean distance - as in previous case, 
but variances are the same for all groups. Objects are assigned 
to group with nearest mean.
}
}
\value{
A list of class \code{rda} containing the following 
components:
\item{call}{The (matched) function call.}
\item{regularization}{vector containing the two regularization 
parameters (gamma, lambda)}
\item{classes}{the names of the classes}
\item{prior}{the prior probabilities for the classes}
\item{error.rate}{apparent error rate (if computation 
was not suppressed), and, if any optimization took place, the
final (cross-validated or bootstrapped) error rate estimate as 
well.}
\item{means}{Group means.}
\item{covariances}{Array of group covariances.}
\item{covpooled}{Pooled covariance.}
\item{converged}{(Logical) indicator of convergence (only for 
Nelder-Mead).}
\item{iter}{Number of iterations actually performed (only for 
Nelder-Mead).}
}
\references{
  Friedman, J.H. (1989): Regularized Discriminant Analysis.
  In: \emph{Journal of the American Statistical Association} 84, 
  165-175.
 
  Press, W.H., Flannery, B.P., Teukolsky, S.A., Vetterling, W.T. (1992): 
  \emph{Numerical Recipes in C}.  Cambridge: Cambridge University Press.
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{
  \code{\link[klaR]{predict.rda}},
  \code{\link[MASS]{lda}}, \code{\link[MASS]{qda}}
}
\examples{
data(iris)
x <- rda(Species ~ ., data = iris, gamma = 0.05, lambda = 0.2)
predict(x, iris)
}
\keyword{multivariate}

\eof
\name{shardsplot}
\alias{shardsplot}
\alias{plot.EDAM}

\title{Plotting Eight Direction Arranged Maps or Self-Organizing Maps}
\description{
  Plotting method for objects of \code{class} \code{\link{EDAM}} or \code{\link[som]{som}}. 
}
\usage{
shardsplot(object, plot.type = c("eight", "four", "points", "n"), 
    expand = 1, stck = TRUE, grd = FALSE, standardize = FALSE, 
    data.or = NA, label = FALSE, plot = TRUE, classes = 0, 
    vertices = TRUE, classcolors = "rainbow", wghts = 0, 
    xlab = "Dimension 1", ylab = "Dimension 2", xaxs = "i", 
    yaxs = "i", ...)

\method{plot}{EDAM}(...)
}

\arguments{
  \item{object}{an object of class \code{EDAM} or \code{som}.}
  \item{plot.type}{a character giving the shape of the shards. 
    Available are \dQuote{\code{eight}} and \dQuote{\code{four}} for octagons resp. rectangles, 
    and \dQuote{\code{points}} for points. If \code{plot.type} is \dQuote{\code{n}}, 
    no shards are plotted at all.}
  \item{expand}{a numeric giving the relative expansion of the axes. 
    A value greater than one implies smaller shards. Varying \code{expand}
    can be sensible for visual reasons.}
  \item{stck}{logical. If \code{TRUE} the cells are varied continously corresponding to 
    the differences of direct neighbors in the origin space. 
    Within this variation the relative order of the cells is always preserved.}
  \item{grd}{logical. If \code{TRUE} (which automatically sets \code{stck} to \code{TRUE}), 
    the variation of cells is restricted to their original discrete values.}
  \item{standardize}{logical. If \code{TRUE}, then the measurements in \code{object$preimages} 
    are standardized before calculating Euclidean distances. 
        Measurements are standardized for each variable by dividing by the variable's 
        standard deviation. Meaningless if \code{object$preimages} is a dissimilarity matrix. }
  \item{data.or}{original data and classes where the first k columns are variables and the (k+1)-th column are the classes.
    If defined and class of \code{object} is \code{som}, \code{data.or} is used to assign a class to each codebook. There
    a codebook receives the class, from which the majority of its assigned objects origins.}
  \item{label}{logical. If \code{TRUE}, the shards are labeled by the rownames of the preimages.}
  \item{plot}{logical. If \code{FALSE}, all graphical output is suppressed.}
  \item{classes}{a vector giving alternative classes for objects of class \code{EDAM}; \code{classes} have to be given in 
    the original order of the data to which \code{\link{EDAM}} was applied.}
  \item{vertices}{logical. If \code{TRUE} the grid is drawn.}
  \item{classcolors}{colors to represent the classes, or a character giving the \emph{colorscale} for the classes. 
    Since now available scales are \code{rainbow}, \code{topo} and \code{gray}.}
  \item{wghts}{ an optional vector of length k giving relative weights of the variables 
    in computing Euclidean distances. Meaningless if \code{object$preimages} is a dissimilarity matrix.}
  \item{xaxs}{see \code{\link{par}}}
  \item{yaxs}{see \code{\link{par}}}
  \item{xlab}{see \code{\link{par}}}
  \item{ylab}{see \code{\link{par}}}
  \item{\dots}{further plotting parameters.}
  }
  
\details{
  If \code{plot.type} is \dQuote{\code{four}} or \dQuote{\code{eight}}, the shape of each shard depends 
  on the relative distances of the actual object 
  or codebook to its up to eight neighbours. If \code{plot.type} is \dQuote{\code{eight}}, \code{shardsplot}
  corresponds to the representation method
  suggested by Cottrell and de Bodt (1996) for Kohonen Self-Organizing Maps. 
  If \code{plot.type} is \dQuote{\code{points}}, \code{shardsplot} reduces to a usual scatter plot.
}
\value{
  The following list is (invisibly) returned:
  \item{Cells.ex}{the images of the visualized data}
  \item{S}{the criterion of the visualization}
}
\references{Cottrell, M., and de Bodt, E. (1996).
  A Kohonen Map Representation to Avoid Misleading Interpretations.
  \emph{Proceedings of the European Symposium on Atrificial Neural Networks}, D-Facto, pp. 103--110.
}
\author{Nils Raabe}

\seealso{
    \code{\link{EDAM}}, \code{\link{TopoS}}, \code{\link[som]{som}}
}
\examples{
# Compute clusters and an Eight Directions Arranged Map for the 
# country data. Plotting the result.
data(countries)
logcount <- log(countries[,2:7])
sdlogcount <- apply(logcount, 2, sd)
logstand <- t((t(logcount) / sdlogcount) * c(1,2,6,5,5,3))
cclasses <- cutree(hclust(dist(logstand)), k = 6)
countryEDAM <- EDAM(logstand, classes = cclasses, sa = FALSE, 
    iter.max = 10, random = FALSE)
plot(countryEDAM, vertices = FALSE, label = TRUE, stck = FALSE)

# Compute and plot a Self-Organizing Map for the iris data
data(iris)
library(som)
irissom <- som(iris[,1:4], xdim = 6, ydim = 14)
shardsplot(irissom, data.or = iris, vertices = FALSE)
opar <- par(xpd = NA)
legend(7.5, 6.1, col = rainbow(3), xjust = 0.5, yjust = 0,
    legend = levels(iris[, 5]), pch = 16, horiz = TRUE)
par(opar)    
}
\keyword{hplot}

\eof
\name{sknn}
\alias{sknn}
\alias{sknn.default}
\alias{sknn.formula}
\alias{sknn.matrix}
\alias{sknn.data.frame}
\title{Simple k nearest Neighbours}
\description{
Function for simple knn classification.
}
\usage{
sknn(x, ...)

\method{sknn}{default}(x, grouping, k = 3,...)
\method{sknn}{data.frame}(x, ...)
\method{sknn}{matrix}(x, grouping, ..., subset, na.action = na.fail)
\method{sknn}{formula}(formula, data = NULL, ..., subset, na.action = na.fail)
}

\arguments{
  
  \item{x}{matrix or data frame containing the explanatory variables 
    (required, if \code{formula} is not given).}
  \item{grouping}{factor specifying the class for each observation 
    (required, if \code{formula} is not given).}
  \item{formula}{formula of the form \code{groups ~ x1 + x2 + ...}. 
    That is, the response is the grouping factor and the right hand side specifies the (non-factor) discriminators.}
  \item{data}{Data frame from which variables specified in \code{formula} are preferentially to be taken.}
  \item{k}{Number of nearest neighbours to use.}
  \item{subset}{An index vector specifying the cases to be used in the
    training sample. (Note: If given, this argument must be named.)}
  \item{na.action}{specify the action to be taken if \code{NA}s are
    found. The default action is for the procedure to fail. An
    alternative is \code{\link{na.omit}}, which leads to rejection of cases with
    missing values on any required variable. (Note: If given, this
    argument must be named.) }
  \item{...}{}
}

\value{
  A list containing the function call. 
}
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}}

\seealso{\code{\link{predict.sknn}}, \code{\link[class]{knn}}}
\examples{
data(iris)
x <- sknn(Species ~ ., data = iris)
}
\keyword{classif}

\eof
\name{stepclass}
\alias{stepclass}
\alias{stepclass.default}
\alias{stepclass.formula}
\alias{print.stepclass}
\alias{plot.stepclass}
\title{Stepwise variable selection for classification}
\description{
Forward/backward variable selection for classification using any specified 
classification function and selecting by estimated classification performance measure from \code{\link{ucpm}}.
}
\usage{
stepclass(x, ...)

\method{stepclass}{default}(x, grouping, method, improvement = 0.05, maxvar = Inf, 
    start.vars = NULL, direction = c("both", "forward", "backward"), 
    criterion = "CR",  fold = 10, cv.groups = NULL, output = TRUE, ...)
\method{stepclass}{formula}(formula, data, method, ...)
}
\arguments{
\item{x}{matrix or data frame containing the explanatory variables 
    (required, if \code{formula} is not given).}
\item{formula}{A formula of the form \code{groups ~ x1 + x2 + ...}. 
    That is, the response is the grouping factor and the right hand side 
    specifies the (non-factor) discriminators. 
    Interaction terms are not supported.}
\item{data}{data matrix (rows=cases, columns=variables)}
\item{grouping}{class indicator vector (a factor)}
\item{method}{character, name of classification function 
    (e.g. \dQuote{\code{\link[MASS]{lda}}}).}
\item{improvement}{least improvement of performance measure desired 
    to include or exclude any variable (<=1)}
\item{maxvar}{maximum number of variables in model}
\item{start.vars}{set variables to start with (indices or names). 
    Default is no variables if \sQuote{\code{direction}} is 
    \dQuote{\code{forward}} or \dQuote{\code{both}}, 
    and all variables if \sQuote{\code{direction}} is \dQuote{\code{backward}}.}
\item{direction}{\dQuote{\code{forward}}, \dQuote{\code{backward}} or 
    \dQuote{\code{both}} (default)}
\item{criterion}{performance measure taken from \code{\link{ucpm}}.}
\item{fold}{parameter for cross-validation; omitted if \sQuote{\code{cv.groups}} is specified.}                                            
\item{cv.groups}{vector of group indicators for cross-validation. 
    By default assigned automatically.}
\item{output}{indicator (logical) for textoutput during computation (slows down computation!)}
\item{...}{further parameters passed to classification function (\sQuote{\code{method}}), e.g. priors etc.}
}
\details{
The classification \dQuote{method} (e.g. \sQuote{\code{\link[MASS]{lda}}}) must have its own 
\sQuote{\code{predict}} method (like \sQuote{\code{\link[MASS]{predict.lda}}} for \sQuote{\code{lda}}) 
that either returns a matrix of posterior probabilities or a list with an element \sQuote{\code{posterior}} containing 
that matrix instead. It must be able to deal with matrices as in \code{method(x, grouping, ...)}

Then a stepwise variable selection is performed. 
The initial model is defined by the provided starting variables; 
in every step new models are generated by including every single 
variable that is not in the model, and by excluding every single 
variable that is in the model. The resulting performance measure for these 
models are estimated (by cross-validation), and if the maximum value of the chosen
criterion is better than \sQuote{\code{improvement}} plus the value so far, the 
corresponding variable is in- or excluded. The procedure stops, if
the new best value is not good enough, or if the specified maximum 
number of variables is reached.

If \sQuote{\code{direction}} is \dQuote{\code{forward}}, the model is only extended (by including 
further variables), if \sQuote{\code{direction}} is \dQuote{\code{backward}}, the model is only 
reduced (by excluding variables from the model).
}
\value{
A list of class \sQuote{\code{stepclass}} containing the following components:
\item{call}{the (matched) function call.}
\item{method}{name of classification function used (e.g. \dQuote{\code{lda}}).}
\item{start.variables}{vector of starting variables.}
\item{process}{data frame showing selection process (included/excluded variables and performance measure).} 
\item{model}{the final model: data frame with 2 columns; indices and names of variables.}
\item{perfomance.measure}{value of the criterion used by \code{\link{ucpm}}}
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}, Irina Czogiel}
\seealso{
\code{\link[stats]{step}}, \code{\link[MASS]{stepAIC}}
}
\examples{
data(iris)
library(MASS)
iris.d <- iris[,1:4]  # the data    
iris.c <- iris[,5]    # the classes 
x <- stepclass(iris.d, iris.c, "lda", start.vars = "Sepal.Width")
y <- stepclass(Species ~ ., data = iris, method = "qda", 
    start.vars = "Sepal.Width", criterion = "AS")  # same as above 
plot(x)
}
\keyword{multivariate}

\eof
\name{svmlight}
\alias{svmlight}
\alias{svmlight.default}
\alias{svmlight.formula}
\alias{svmlight.matrix}
\alias{svmlight.data.frame}
\alias{svmlight.file}
\title{Interface to SVMlight}
\description{
Function to call SVMlight from R for classification. Multiple group
classification is done with the one-against-rest partition of data.  
}
\usage{
svmlight(x, ...)

\method{svmlight}{default}(x, grouping, temp.dir = NULL, pathsvm = NULL, del = TRUE,
    type = "C", class.type = "oaa", svm.options = NULL, prior = NULL, 
    out = FALSE, ...)
\method{svmlight}{data.frame}(x, ...)
\method{svmlight}{matrix}(x, grouping, ..., subset, na.action = na.fail)
\method{svmlight}{formula}(formula, data = NULL, ..., subset, na.action = na.fail)
}

\arguments{
  \item{x}{matrix or data frame containing the explanatory variables 
    (required, if \code{formula} is not given).}
  \item{grouping}{factor specifying the class for each observation 
    (required, if \code{formula} is not given).}
  \item{formula}{formula of the form \code{groups ~ x1 + x2 + ...}. 
    That is, the response is the grouping factor and the right hand side specifies the (non-factor) discriminators.}
  \item{data}{Data frame from which variables specified in \code{formula} are preferentially to be taken.}
  \item{temp.dir}{directory for temporary files.}
  \item{pathsvm}{Path to SVMlight binaries (required, if path os unknown by the OS).}
  \item{del}{Logical: whether to delete temporary files}
  \item{type}{Perform \code{"C"}=Classification or \code{"R"}=Regression}
  \item{class.type}{Multiclass scheme to use. See details.}
  \item{svm.options}{Optional parameters to SVMlight.
  
    For further details see: \dQuote{How to use} on \url{http://svmlight.joachims.org/}.
  }
  \item{prior}{A Priori probabilities of classes.}
  \item{out}{Logical: whether SVMlight output ahouild be printed on console 
    (only for Windows OS.)}
  \item{subset}{An index vector specifying the cases to be used in the
    training sample. (Note: If given, this argument must be named.)}
  \item{na.action}{specify the action to be taken if \code{NA}s are
    found. The default action is for the procedure to fail. An
    alternative is \code{\link{na.omit}}, which leads to rejection of cases with
    missing values on any required variable. (Note: If given, this
    argument must be named.) }
  \item{...}{}
  
}
\details{
  Function to call SVMlight from R for classification (\code{type="C"}). 
  SVMlight is an implementation of Vapnik's Support Vector Machine. It
  is written in C by Thorsten Joachims. On the homepage (see below) the
  source-code and several binaries for SVMlight are available. If more
  then two classes are given the SVM is learned by the one-against-all
  scheme (\code{class.type="oaa"}). That means that each class is trained against the other K-1
  classes. The class with the highest decision function in the SVM
  wins. So K SVMs have to be learned.
  If \code{class.type="oao"} each class is tested against every other and the final class is elected
  by a majority vote.

  If \code{type="R"} a SVM Regression is performed.
}
\value{
  A list containing the function call and the result of SVMlight. 
}
\references{\url{http://svmlight.joachims.org/}}
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}, Andrea Preusser}
\seealso{\code{\link{predict.svmlight}},\code{\link[e1071]{svm}},
}
\examples{
\dontrun{
## Only works if the svmlight binaries are in the path.
data(iris)
x <- svmlight(Species ~ ., data=iris)
}
}
\keyword{classif}

\eof
\name{triframe}
\alias{triframe}
\title{Barycentric plots}
\description{Function to add a frame to an existing (barycentric) plot.}
\usage{
triframe(label = 1:3, label.col = 1, cex = 1, ...)
}
\arguments{
  \item{label}{labels for the three corners of the plot.}
  \item{label.col}{text color for labels.}
  \item{cex}{Magnification factor for label text relative to the default.}
  \item{\dots}{Further graphical parameters passed to \code{\link{trilines}}.}
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{\code{\link{triplot}}, \code{\link{trilines}}, \code{\link{trigrid}}, \code{\link{centerlines}}}
\examples{
triplot(grid = TRUE, frame = FALSE)     # plot without frame 
some.triangle <- rbind(c(0, 0.65, 0.35), c(0.53, 0.47, 0), 
                       c(0.72, 0, 0.28))[c(1:3, 1), ]
trilines(some.triangle, col = "red", pch = 16, type = "b")
triframe(label = c("left", "top", "right"), col = "blue", 
         label.col = "green3")          # frame on top of points 
}
\keyword{aplot}

\eof
\name{trigrid}
\alias{trigrid}
\title{Barycentric plots}
\description{Function to add a grid to an existing (barycentric) plot.}
\usage{
trigrid(x = seq(0.1, 0.9, by = 0.1), y = NULL, z = NULL, 
    lty = "dashed", col = "grey", ...)
}

\arguments{
  \item{x}{Values along which to draw grid lines for first dimension 
    (or all dimensions if \code{y} and \code{z} omitted). 
  For NO grid lines in some dimensions just supply an \code{NA}.}
  \item{y}{Grid lines for second dimension.}
  \item{z}{Grid lines for third dimension.}
  \item{lty}{Line type (see \code{\link{par}}).}
  \item{col}{Line colour (see \code{\link{par}}).}
  \item{\dots}{Further graphical parameters passed to \code{\link{trilines}}.}
}
\details{
Grid lines illustrate the set of points for which one of the dimensions is held constant; 
e.g. horizontal lines contain all points with a certain value y for the second dimension, 
connecting the two extreme points (0,y,1-y) and (1-y,y,0).

Grids may be designed more flexible than with \code{triplot}'s \code{grid} option.}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{\code{\link{triplot}}, \code{\link{trilines}}, \code{\link{triframe}}, \code{\link{centerlines}}}
\examples{
triplot(grid = FALSE)
trigrid(c(1/3, 0.5)) # same grid for all 3 dimensions 

triplot(grid = c(1/3, 0.5))  # (same effect) 

triplot(grid = FALSE)
# different grids for all dimensions:
trigrid(x = 1/3, y = 0.5, z = seq(0.2, 0.8, by=0.2))  

triplot(grid = FALSE)
# grid for third dimension only:
trigrid(x = NA, y = NA, z = c(0.1, 0.2, 0.4, 0.8))  
}

\keyword{aplot}

\eof
\name{triperplines}
\alias{triperplines}
\title{Barycentric plots}
\description{Function to add a point and the corresponding perpendicular lines to all three 
    sides to an existing (barycentric) plot.}
\usage{
triperplines(x, y = NULL, z = NULL, lcol = "red", pch = 17, ...)
}
\arguments{
  \item{x}{fraction of first component
    OR 3-element vector (for all three components, omitting \code{y} and \code{z}).}
  \item{y}{(optional) fraction of second component.}
  \item{z}{(optional) fraction of third component.}
  \item{lcol}{line color}
  \item{pch}{plotting character. \code{pch = 0} for no point}
  \item{\dots}{Further graphical parameters (see \code{\link{points}}, \code{\link{lines}} and \code{\link{par}}).}
}
\details{
Adds a (single!) point and lines to an existing plot (generated by \code{\link{triplot}}).
The lines originate from the point and run (perpendicular) towards all three sides. 
The lengths (and proportions) of these lines are identical to those of \code{x}, \code{y} and \code{z}.
}
\value{
a 2-column-matrix containing plot coordinates.
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{\code{\link{triplot}}, \code{\link{tripoints}}, \code{\link{trilines}}, \code{\link{tritrafo}}}
\examples{
triplot()  # empty plot 
triperplines(1/2, 1/3, 1/6)
}
\keyword{aplot}

\eof
\name{triplot}
\alias{triplot}
\title{Barycentric plots}
\description{
Function to produce triangular (barycentric) plots 
illustrating proportions of 3 components, 
e.g. discrete 3D-distributions or mixture fractions that sum up to 1.
}
\usage{
triplot(x = NULL, y = NULL, z = NULL, main = "", frame = TRUE, 
    label = 1:3, grid = seq(0.1, 0.9, by = 0.1), center = FALSE, 
    set.par = TRUE, ...)
}
\arguments{
  \item{x}{Vector of fractions of first component
    OR 3-column matrix containing all three components (omitting \code{y} and \code{z})
    OR 3-element vector (for all three components, omitting \code{y} and \code{z}).}
  \item{y}{(Optional) vector of fractions of second component.}
  \item{z}{(Optional) vector of fractions of third component.}
  \item{main}{Main title}
  \item{frame}{Controls whether a frame (triangle) and labels are drawn.}
  \item{label}{(Character) vector of labels for the three corners.}
  \item{grid}{Values along which grid lines are to be drawn (or \code{FALSE} for no grid at all). 
    Default is steps of 10 percent.}
  \item{center}{Controls whether or not to draw centerlines at which there is a 
    \sQuote{tie} between any two dimensions (see also \code{\link{centerlines}}).}
  \item{set.par}{Controls whether graphical parameter \code{mar} is set so 
    the plot fills the window (see \code{\link{par}}).}
  \item{\dots}{Further graphical parameters passed to \code{\link{trilines}}.}
}
\details{
The barycentric plot illustrates the set of points (x,y,z) with x,y,z between 0 and 1 and x+y+z=1; 
that is, the triangle spanned by (1,0,0), (0,1,0) and (0,0,1) in 3-dimensional space.
The three dimensions x, y and z correspond to lower left, upper and lower right corner of the plot.
The greater the share of x in the proportion, the closer the point is to the lower left corner;
Points on the opposite (upper right) side have a zero x-fraction.
The grid lines show the points at which one dimension is held constant, horizontal lines for 
example contain points with a constant second dimension.
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{
\code{\link{tripoints}}, \code{\link{trilines}}, \code{\link{triperplines}}, \code{\link{trigrid}}, 
\code{\link{triframe}} for points, lines and layout, \code{\link{tritrafo}} for placing labels,
and \code{\link{quadplot}} for the same in 4 dimensions.
}
\examples{
# illustrating probabilities: 
triplot(label = c("1, 2 or 3", "4 or 5", "6"), 
    main = "die rolls: probabilities", pch = 17)
triperplines(1/2, 1/3, 1/6)

# expected... 
triplot(1/2, 1/3, 1/6, label = c("1, 2 or 3", "4 or 5", "6"), 
    main = "die rolls: expected and observed frequencies", pch = 17)
# ... and observed frequencies. 
dierolls <- matrix(sample(1:3, size = 50*20, prob = c(1/2, 1/3, 1/6), 
                          replace = TRUE), ncol = 50)
frequencies <- t(apply(dierolls, 1, 
    function(x)(summary(factor(x, levels = 1:3)))) / 50)
tripoints(frequencies)

# LDA classification posterior: 
data(iris)
require(MASS)
pred <- predict(lda(Species ~ ., data = iris),iris)
plotchar <- rep(1,150)
plotchar[pred$class != iris$Species] <- 19
triplot(pred$posterior, label = colnames(pred$posterior), 
        main = "LDA posterior assignments", center = TRUE, 
        pch = plotchar, col = rep(c("blue", "green3", "red"), rep(50, 3)), 
        grid = TRUE)
legend(x = -0.6, y = 0.7, col = c("blue", "green3", "red"), 
    pch = 15, legend = colnames(pred$posterior))
}
\keyword{aplot}

\eof
\name{tripoints}
\alias{tripoints}
\alias{trilines}
\title{Barycentric plots}
\description{Function to add points or lines to an existing (barycentric) plot.}
\usage{
tripoints(x, y = NULL, z = NULL, ...)
trilines(x, y = NULL, z = NULL, ...)
}
\arguments{
  \item{x}{Vector of fractions of first component
OR 3-column matrix containing all three components (omitting \code{y} and \code{z})
OR 3-element vector (for all three components, omitting \code{y} and \code{z}).}
  \item{y}{(optional) vector of fractions of second component.}
  \item{z}{(optional) vector of fractions of third component.}
  \item{\dots}{Further graphical parameters (see \code{\link{points}} and \code{\link{par}}).}
}
\details{
Adds points or lines to an existing plot (generated by \code{\link{triplot}}).
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{\code{\link{points}}, \code{\link{lines}}, \code{\link{triplot}}, \code{\link{tritrafo}}, \code{\link{centerlines}}}
\examples{
triplot()  # empty plot 
tripoints(0.1, 0.2, 0.7)                        # a point 
tripoints(c(0.2, 0.6), c(0.3, 0.3), c(0.5, 0.1),
    pch = c(2, 6))                              # two points
trilines(c(0.1, 0.6), c(0.2, 0.3), c(0.7, 0.1), 
    col = "blue", lty = "dotted")               # a line 

trilines(centerlines(3))
}
\keyword{aplot}

\eof
\name{tritrafo}
\alias{tritrafo}
\title{Barycentric plots}
\description{
Function to carry out the transformation into 2D space
for \code{\link{triplot}}, \code{\link{trilines}} etc.
}
\usage{
tritrafo(x, y = NULL, z = NULL, check = TRUE, tolerance = 0.0001)
}
\arguments{
  \item{x}{Vector of fractions of first component
OR 3-column matrix containing all three components (omitting \code{y} and \code{z})
OR 3-element vector (for all three components, omitting \code{y} and \code{z}).}
  \item{y}{(optional) vector of fractions of second component.}
  \item{z}{(optional) vector of fractions of third component.}
  \item{check}{if \code{TRUE}, it is checked whether \code{x+y+z=1} and \code{x,y,z>=0} for all cases.}
  \item{tolerance}{tolerance for above sum check.}
}
\details{
Projects the mixture given by \code{x}, \code{y}, and \code{z} 
with \code{x}, \code{y}, \code{z} between one and zero and \code{x+y+z=1} into
a two-dimensional space.

For further details see \code{\link{triplot}}.
}
\value{
A matrix with two columns corresponding to the two dimensions.
}
\author{Christian Rver, \email{roever@statistik.uni-dortmund.de}}
\seealso{\code{\link{triplot}}, \code{\link{tripoints}}, \code{\link{trilines}}, \code{\link{trigrid}}}
\examples{
tritrafo(0.1, 0.2, 0.7)
tritrafo(0.1, 0.2, 0.6) # warning 

triplot()
points(tritrafo(0.1, 0.2, 0.7), col="red")
tripoints(0.1, 0.2, 0.7, col="green")  # the same

tritrafo(c(0.1,0.2), c(0.3,0.4), c(0.6,0.4))
tritrafo(diag(3))

point <- c(0.25,0.6,0.15)
triplot(point, pch=16)
text(tritrafo(point), "(0.25, 0.60, 0.15)", adj=c(0.5,2)) # add a label 
}
\keyword{dplot}

\eof
\name{ucpm}
\alias{ucpm}
\title{Uschi's classification performance measures}
\description{
Function to calculate the Correctness Rate, the Accuracy, the Ability to Seperate and the Confidence of 
a classification rule.
}
\usage{
ucpm(m, tc, ec = NULL)
}
\arguments{
  \item{m}{matrix of (scaled) membership values}
  \item{tc}{vector of true classes}
  \item{ec}{vector of estimated classes (only required if scaled membership values are used)}
}
\details{ 
\itemize{
\item The \emph{correctness rate} is the estimator for the correctness of a classification rule (1-error rate). 

\item The \emph{accuracy} is based on the euclidean distances between (scaled) membership vectors and the vectors 
representing the true class corner. These distances are standardized so that a measure of 1 is achieved
if all vectors lie in the correct corners and 0 if they all lie in the center. 

\item Analougously, the \emph{ability to seperate} is based on the distances between (scaled) membership 
vectors and the vector representing the corresponding assigned class corner. 

\item The \emph{confidence} is the mean of the membership values of the assigned classes. 
}

}
\value{
A list with elements:
  \item{CR}{Correctness Rate}
  \item{AC}{Accuracy}
  \item{AS}{Ability to Seperate}
  \item{CF}{Confidence}
  \item{CFvec}{Confidence for each (true) class}
}

\references{Garczarek, Ursula Maria (2002): Classification rules in standardized partition spaces.
            Dissertation, University of Dortmund. 
            URL \url{http://eldorado.uni-dortmund.de:8080/FB5/ls7/forschung/2002/Garczarek}}
            
\author{Karsten Luebke, \email{luebke@statistik.uni-dortmund.de}}
\examples{
library(MASS)
data(iris)
ucpm(predict(lda(Species ~ ., data = iris))$posterior, iris$Species)
}
\keyword{classif}

\eof
